@@ -146,8 +146,10 @@ $App->log("CA $CURRENT_ACTION",2,'SPAF2');
 $App->view = $CURRENT_ACTION;
 
 $tmpAccess = $App->getSession('tmpAccess');
-if ($tmpAccess) {
-    $App->setAuthz($tmpAccess,0);
+if (is_array($tmpAccess)) {
+    foreach ($tmpAccess as $_tmpAccessVal) {
+        $App->setAuthz($_tmpAccessVal,0);
+    }
 }
 
 /* *** PRE CTRL HOOK ***/
